@@ -4,6 +4,7 @@ package Net::FireEagle;
 use strict;
 use LWP;
 use CGI;
+use Carp;
 require Net::OAuth::Request;
 require Net::OAuth::RequestTokenRequest;
 require Net::OAuth::AccessTokenRequest;
@@ -16,7 +17,7 @@ BEGIN {
     }
 }
 
-our $VERSION = '0.9';
+our $VERSION = '1.0';
 our $DEBUG   = 0;
 
 # FireEagle Endpoint URLs
@@ -50,7 +51,7 @@ Net::FireEagle - access Yahoo's new FireEagle location service
                                    access_token_secret => $access_token_secret );
 
     # Send this to user to grant authorization for this app
-    my $auth_url = $fe->authorization_url;
+    my $auth_url = $fe->get_authorization_url;
     # ... and request an access token
     # Note: you can save these in DB to restore previous Fire Eagle oauth session
     my ($access_token, $access_token_secret) = $fe->request_access_token;
@@ -59,6 +60,13 @@ Net::FireEagle - access Yahoo's new FireEagle location service
     my $access_token = $fe->access_token;
     my $access_token_secret = $fe->access_token_secret;
 
+    # in the case of a web app, you want to save the request tokens
+    # (and/or set them)
+    my $request_token = $fe->request_token;
+    my $request_token_secret = $fe->request_token_secret;
+    $fe->request_token( $request_token );
+    $fe->request_token_secret( $request_token_secret );
+
     # Can't query or update location without authorization
     my $loc = $fe->location;                     # returns xml
     my $loc = $fe->location( format => 'xml'  ); # returns xml
@@ -230,6 +238,37 @@ sub access_token_secret {
     return $self->_access('access_token_secret', $@);
 }
 
+=head2 request_token [request_token]
+
+Returns the current request token.
+
+Can optionally set a new token.
+
+=cut
+
+sub request_token {
+    my $self = shift;
+    $self->_access( 'request_token', $@ );
+}
+
+
+=head2 request_token_secret [request_token_secret]
+
+Returns the current request token secret.
+
+Can optionally set a new secret.
+
+=cut
+
+sub request_token_secret {
+    my $self = shift;
+    return $self->_access( 'request_token_secret', $@ );
+}
+
+
+
+
+
 sub _access {
     my $self = shift;
     my $key  = shift;
